#ifndef QT_FEATURES_Charts_src_charts_qtcharts_config_h_H
#define QT_FEATURES_Charts_src_charts_qtcharts_config_h_H

#define QT_FEATURE_charts_line_chart 1

#define QT_FEATURE_charts_spline_chart 1

#define QT_FEATURE_charts_area_chart 1

#define QT_FEATURE_charts_scatter_chart 1

#define QT_FEATURE_charts_bar_chart 1

#define QT_FEATURE_charts_pie_chart 1

#define QT_FEATURE_charts_boxplot_chart 1

#define QT_FEATURE_charts_candlestick_chart 1

#define QT_FEATURE_charts_datetime_axis 1


#endif // QT_FEATURES_Charts_src_charts_qtcharts_config_h_H
